# == Class centrify::install
#
class centrify::install {
  $arch = $::hardwaremodel ? {
    'i686'  => 'i386',
    default => $::hardwaremodel
  }

  $package_type = $::operatingsystem ? {
    'RedHat' => 'rhel3',
    'CentOS' => 'rhel3',
    default  => 'deb5'
  }
  $package_suffix = $::operatingsystem ? {
    'RedHat' => 'rpm',
    'CentOS' => 'rpm',
    default  => 'deb'
  }

  # Download suite from centrify.com
  if $centrify::download_centrify == true {
    $tarball_filename = regsubst($centrify::package_source, '^.+/(.+?)$', '\1')

    $local_tarball = "${centrify::working_dir}/${tarball_filename}"

    file { $centrify::working_dir: ensure => directory } ->
    file { "${centrify::working_dir}/centrify":
      ensure => directory,
      mode   => '0770',
    }

    exec { 'download_centrify':
      command => "/usr/bin/wget ${centrify::package_source}",
      cwd     => $centrify::working_dir,
      notify  => Exec['uncompress_centrify'],
      creates => $local_tarball,
      unless  => "/bin/ls ${local_tarball}"
    }

    # Unpack suite
    exec { 'uncompress_centrify':
      cwd         => $centrify::working_dir,
      command     => "/bin/tar -xf ${local_tarball} -C ${centrify::working_dir}/centrify",
      refreshonly => true,
      require     => [Exec['download_centrify'], File["${centrify::working_dir}/centrify"]],
      creates     => "${centrify::working_dir}/centrify/install.sh",
      notify      => Exec['rename_package']
    }

    exec { 'rename_package':
      cwd         => $centrify::working_dir,
      command     => "/bin/bash -c '/bin/mv ${centrify::working_dir}/centrify/centrifydc-[0-9]*-${package_type}-${arch}.${package_suffix} ${centrify::working_dir}/centrify.${package_suffix}'",
      creates     => "${centrify::working_dir}/centrify.${package_suffix}",
      require     => Exec['uncompress_centrify'],
      refreshonly => true,
      notify      => Package[$centrify::package_name],
    }

  }

  # Install wanted packages - default DC only
  $real_source = $centrify::download_centrify ? {
    true    => "${centrify::working_dir}/centrify.${package_suffix}",
    default => $centrify::package_source
  }

  $provider = $::osfamily ? {
    'Debian' => 'dpkg',
    'RedHat' => 'rpm',
    default  => 'dpkg'
  }

  $package_require = $centrify::download_centrify ? {
    true => Exec['rename_package'],
    default => undef,
  }

  package { $centrify::package_name:
    ensure   => $centrify::ensure,
    provider => $provider,
    source   => $real_source,
    require  => $package_require,
  }
}
