require 'spec_helper'

describe 'centrify' do

  context 'supported operating systems' do
    ['Debian', 'RedHat'].each do |osfamily|
      describe "centrify class without any parameters on #{osfamily}" do
        #        describe "centrify class without any parameters" do
        let(:params) {{ }}
        let(:facts) {{
            :osfamily => osfamily,
          }}

        it { should compile.with_all_deps }

        it { should contain_class('centrify::params') }
        it { should contain_class('centrify::install').that_comes_before('centrify::config') }
        it { should contain_class('centrify::config') }
        it { should contain_class('centrify::service').that_subscribes_to('centrify::config') }

        it { should contain_service('centrifydc') }
#        it { should contain_package('centrifydc').with_ensure('present') }
      end
    end

    context "On a Debian OS with no package name specified" do
      let :facts do { :osfamily => 'Debian' } end
      it { should contain_package('centrifydc').with( { 'ensure' => 'present' } ) }
    end

    context "On a RedHat OS with no package name specified" do
      let :facts do { :osfamily => 'RedHat' } end
      it { should contain_package('CentrifyDC').with( { 'ensure' => 'present' } ) }
    end

  end

  context 'unsupported operating system' do
    describe 'centrify class without any parameters on Solaris/Nexenta' do
      let(:facts) {{
          :osfamily        => 'Solaris',
          :operatingsystem => 'Nexenta',
        }}

      it { expect { should contain_package('centrify') }.to raise_error(Puppet::Error, /Nexenta not supported/) }
    end
  end
end
